@@ -17,6 +17,7 @@ limitations under the License.
 package machine
 
 import (
+	"context"
 	"log"
 	"os"
 	"path/filepath"
@@ -27,10 +28,12 @@ import (
 	"k8s.io/client-go/rest"
 	"sigs.k8s.io/controller-runtime/pkg/envtest"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
-	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 )
 
-var cfg *rest.Config
+var (
+	cfg *rest.Config
+	ctx = context.Background()
+)
 
 func TestMain(m *testing.M) {
 	t := &envtest.Environment{
@@ -48,27 +51,16 @@ func TestMain(m *testing.M) {
 	os.Exit(code)
 }
 
-// SetupTestReconcile returns a reconcile.Reconcile implementation that delegates to inner and
-// writes the request to requests after Reconcile is finished.
-func SetupTestReconcile(inner reconcile.Reconciler) (reconcile.Reconciler, chan reconcile.Request) {
-	requests := make(chan reconcile.Request)
-	fn := reconcile.Func(func(req reconcile.Request) (reconcile.Result, error) {
-		result, err := inner.Reconcile(req)
-		requests <- req
-		return result, err
-	})
-	return fn, requests
-}
-
 // StartTestManager adds recFn
-func StartTestManager(mgr manager.Manager, t *testing.T) chan struct{} {
+func StartTestManager(mgr manager.Manager, t *testing.T) (chan struct{}, chan error) {
 	t.Helper()
 
 	stop := make(chan struct{})
+	errs := make(chan error, 1)
+
 	go func() {
-		if err := mgr.Start(stop); err != nil {
-			t.Fatalf("error starting test manager: %v", err)
-		}
+		errs <- mgr.Start(stop)
 	}()
-	return stop
+
+	return stop, errs
 }
